`pip install` output should be stripped:


```python
%pip install pytest
```

Should be markdown (implicit)

Should be markdown (explicit)

Should be markdown (tags)


```python

# Should be code

print("2 + 2")

```

    2 + 2



```python

# Should be code (tags)

print(2 + 2)

```

    4

